@@ -21,4 +21,4 @@ fa=group25.fa
     lamassemble -c $mat group25-aln.fa
     lamassemble -c -fFASTQ $mat group25-aln.fa
     lamassemble PromethION-2019 $fa
-} 2>&1 | diff -u lama-tests.out -
+} 2>&1 | grep -v 'lamassemble: using 2 out of 3 sequences' | diff -u lama-tests.out -
